#
# spec file for package xyscan
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if 0%{?suse_version} >= 1550
%bcond_without  qt6
%else
# Leap still only provides qt5
%bcond_with     qt5
%endif
Name:           xyscan
Version:        4.64
Release:        1.12
Summary:        Data extractor for data points from graphical plots
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://rhig.physics.yale.edu/~ullrich/software/xyscan/
Source0:        https://rhig.physics.yale.edu/~ullrich/software/xyscan/Distributions/%{version}/xyscan-%{version}-src.tgz
# PATCH-FIX-UPSTREAM no-build-date.patch -- delete build date from source
Patch0:         no-build-date.patch
# PATCH-FEATURE-UPSTREAM allow-qt6-also-on-non-mac.patch -- Allow building with QT6 (already supported on Mac)
Patch1:         allow-qt6-also-on-non-mac.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
%if %{with qt6}
BuildRequires:  qt6-tools-linguist
BuildRequires:  cmake(Qt6Charts)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Multimedia)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  pkgconfig(poppler-qt6)
%else
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig(Qt5Charts)
BuildRequires:  pkgconfig(Qt5Core) >= 5.14
BuildRequires:  pkgconfig(Qt5Gui) >= 5.14
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(poppler-qt5)
%endif
Requires:       hicolor-icon-theme
Recommends:     %{name}-doc = %{version}

%description
xyscan is a tool for scientists in need of extracting data points,
i.e. numeric values, from a plot.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
Requires:       %{name} = %{version}
BuildArch:      noarch

%description doc
xyscan is a tool for scientists in need of extracting data points,
i.e. numeric values, from a plot.

This package contains the documentation and help files for %{name}.

%prep
%autosetup -p1 -n %{name}

# Change hard-coded directories to proper macros
sed -i 's|/usr/local|%{_prefix}|' xyscan.pro
sed -i 's|/usr/lib|%{_libdir}|' xyscan.pro
sed -i 's|\$\$PREFIX/share/xyscan/docs|%{_docdir}/%{name}/html|' xyscan.pro
sed -i 's|/usr/share/doc/xyscan/docs|%{_docdir}/%{name}/html|' src/*.cpp

# Fix wrong-file-end-of-line-encoding
sed -i 's/\r$//' license.txt

%build
%if %{with qt6}
%qmake6
%else
%qmake5
%endif
%make_jobs

%install
%if %{with qt6}
%qmake6_install
%else
%qmake5_install
%endif

%suse_update_desktop_file -c %{name} %{name} "A visualization tool for 3D datasets" %{name} %{name} Science Math

# Install application icons
for px in 16 24 32 48 64 128 256 512 ; do
install -Dm 664 images/xyscanLogo${px}.png %{buildroot}%{_datadir}/icons/hicolor/${px}x${px}/apps/%{name}.png
done
install -Dm 664 images/xyscanIcon.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

%post
%icon_theme_cache_post

%postun
%icon_theme_cache_postun

%files
%license gpl.txt license.txt
%doc README.txt
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%exclude %{_docdir}/%{name}/html/

%files doc
%license gpl.txt license.txt
%{_docdir}/%{name}/html/

%changelog
* Sun May  1 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 4.6.4 (4.64):
  * xyscan is now build using Qt6.3 which includes the QtPdf module
    again. This makes loading PDFs faster and easier to maintain.
  * The xyscan build is now universal supporting Intel and Apple M1
    architectures.
  * Fixed issue related to saving data points in a ROOT macro that
    caused a value of 0 to be saved instead of the correct value.
  * When loading a second plot in xyscan the data table was not
    properly reset. This is fixed now.
  * New is the path measuring tool that allows for the measurement
    of polylines in maps and technical drawings.
  * A bug in storing scanned data as ROOT macro when no error bars
    were present was fixed.
  * Various bug fixes.
- Rebased no-build-date.patch
- Added allow-qt6-also-on-non-mac.patch (reported upstream by email)
- Upstream still supports QT5 for (only) Linux, so for Leap we stick
  with QT5 and for Factory we use QT6 for smooth transition.
* Fri Sep  4 2020 Dirk Mueller <dmueller@suse.com>
- update to 4.5.0 (4.50):
  Most important change is probably the update of the error bar scan mechanism.
  It is now possible to scan several x and y-errors (e.g. stat. and sys.
  uncertainties) in one scan.
  It now has a multi-lingual interface (French and German), although the
  documentation remains available in English only.
  Improvements were made to make full use of screens with a pixel device ratios >
  1 (most modern high-resolution screens).
  The status bar on the bottom now features an additional coordinate display on
  the right.
  A Significant Digits command was added to the Edit menu that allows to modify
  the precision of the displayed coordinates and distances. This also affects the
  numbers saved in a file (or ROOT macro).
  CSV was added as a third possible format for saving scanned data. This allows
  to import the data into spreadsheet applications such as Excel and Numbers.
  A new experimental histogram display was added that shows the grayscale density
  around the cursor. In certain cases this might help to place markers or scan
  points more accurately.
  The format of the data table can now be toggled between stretched and resized
  to content and the alignment of the numbers can be toggled between left, right,
  and center.
* Thu Dec  6 2018 Jan Engelhardt <jengelh@inai.de>
- Grammar fixes for the description.
* Tue Dec  4 2018 Todd R <toddrme2178@gmail.com>
- Update to version 4.3.0 (4.30)
  * introduces a Measure Tool. It allows one to measure distances
    in pixel, plot, and user defined units.
  * Added a warning dialog to save (or discard) data when a new
    plot is loaded and the current data is not saved.
* Sun Oct 16 2016 toddrme2178@gmail.com
- Update to version 4.1.0 (4.10)
  * The Windows version gets reintroduced in form a convenient
    binary installer.
  * For now the support of pdf files had to be dropped in the
    Window version.
  * On the Mac (and to some extent on Windows) it is now possible
    to open an image file with xyscan directly from the Finder
    (right-click then Open With). Works with the major file types
    such as png, gif, tif, jpg, and pdf.
- Update to version 4.0.0 (4.00)
  * This is a major rewrite of many parts of xyscan.
  * Changes were made to the GUI and support for PDF was added.
  * Some features that had stopped working, such as drag and drop,
    were restored.
  * The documentation was updated and simplified.
  * For certain platform-screen combinations (e.g. Retina) it is
    now possible to use even finer cursor adjustment steps than
    before (alt/option+arrow).
  * For this version, non-English language support was dropped.
- Update to version 3.3.3 (3.33)
  * This is only a maintenance release mostly for Mac OS 10.9.
  * xyscan now uses Qt 5.3. Few internal changes that were
    necessary due to the new Qtversion but nothing that affects
    the functionality.
  * For the Mac some adjustments were made to deal with Retina
    displays.
  * This version was not tested on Windows or Linux.
- Update to version 3.3.2 (3.32)
  * No upstream changelog.
- Many modifications to the .spec file to support Qt5.
- Rebase no-build-date.patch
- Change docs.patch to a sed script to support variable
  documentation installation directories.
- Use %%suse_update_desktop_file to dynamically generate .desktop
  file instead of using a separate source file.
* Sun Dec 23 2012 dmitry_r@opensuse.org
- Spec file cleanup
* Sun Sep 30 2012 dmitry_r@opensuse.org
- Fix desktop file
- Fix SLE build
* Sun Aug 12 2012 dmitry_r@opensuse.org
- fix "file contains current date" for xyscan binary
- fix documentation place
* Thu Aug  9 2012 dmitry_r@opensuse.org
- Initial package
- Version 3.3.1
